# temp while the test still fails
ipsec whack --impair suppress_retransmits
ipsec auto --up north-east
echo done
